@@ -80,6 +80,7 @@ bool setupReply(bool all, bool fwd);
 bool imapBufferPresent(void);
 bool imapBuffer(char *line);
 bool imap1rf();
+void lsEnvelope(const char *lsmode);
 bool folderDescend(const char *path, bool rf);
 bool folderSearch(const char *path, char *search, bool rf);
 bool mailDescend(const char *path, char cmd);
@@ -325,8 +326,8 @@ unsigned pstLength(const uchar *s) ;
 pst clonePstring(const uchar *s) ;
 void copyPstring(pst s, const pst t) ;
 int comparePstring(const uchar * s, const uchar * t);
-int fdIntoMemory(int fd, char **data, int *len, bool inparts);
-int fileIntoMemory(const char *filename, char **data, int *len, bool inparts);
+int fdIntoMemory(int fd, char **data, int *len, int inparts);
+int fileIntoMemory(const char *filename, char **data, int *len, int inparts);
 bool memoryOutToFile(const char *filename, const char *data, int len);
 void truncate0(const char *filename, int fh);
 long long bufferSizeW(const Window *w, bool browsing);
@@ -379,6 +380,7 @@ void unpercentURL(char *url) ;
 void unpercentString(char *s) ;
 char *percentURL(const char *start, const char *end);
 bool looksPercented(const char *start, const char *end);
+char *percentString(const char *start, const char *end);
 char *htmlEscape0(const char *s, bool para);
 #define htmlEscape(s) htmlEscape0((s), false)
 bool isURL(const char *url) ;
