@@ -2463,6 +2463,7 @@ static CURL *http_curl_init(struct i_get *g)
 	curl_easy_setopt(h, CURLOPT_PROGRESSDATA, g);
 	if(pubKey)
 		curl_easy_setopt(h, CURLOPT_SSH_PUBLIC_KEYFILE, pubKey);
+	curl_easy_setopt(h, CURLOPT_BUFFERSIZE, 0x00000l);
 	curl_easy_setopt(h, CURLOPT_CONNECTTIMEOUT, webTimeout);
 	curl_easy_setopt(h, CURLOPT_USERAGENT, currentAgent);
 	curl_easy_setopt(h, CURLOPT_SSLVERSION, (long)CURL_SSLVERSION_DEFAULT);
@@ -2799,7 +2800,6 @@ ebcurl_debug_handler(CURL * handle, curl_infotype info_desc, char *data,
 // We need to explicitly cast as apparently curl wants to pass us a void type pointer these days
         struct i_get *g = (struct i_get *) client;
 
-
 // There's a special case where this function is used
 // by the imap client to see if the server is move capable.
 // Unfortunately this check runns all the while we are at db4, even for http etc,
@@ -2814,6 +2814,17 @@ ebcurl_debug_handler(CURL * handle, curl_infotype info_desc, char *data,
 				break;
 			}
 	}
+
+	if (info_desc == CURLINFO_HEADER_IN &&
+	    size > 12 && !strncmp(data + 1, "002 NO ", 7)) {
+		const char *s = data + 8;
+		const char *t = data + size;
+		while(isspaceByte(t[-1])) --t;
+		char *v = pullString(s, t - s);
+		puts(v);
+		nzFree(v);
+	}
+
 	if (debugLevel < 4)
 		return 0;
 
@@ -3272,7 +3283,7 @@ So check for serverData null here. Once again we pop the frame.
 			return 0;
 		}
 	} else {
-		serverData = cloneString("<body></body>");
+		serverData = cloneString("<head></head><body></body>");
 		serverDataLen = strlen(serverData);
 	}
 
