@@ -739,7 +739,7 @@ It is more efficient if PARTSIZE is a multiple of the page size.
 *********************************************************************/
 #define FILEPARTSIZE 0x4000000
 
-int fdIntoMemory(int fd, char **data, int *len, bool inparts)
+int fdIntoMemory(int fd, char **data, int *len, int inparts)
 {
 	int length, n, j;
 	const int blocksize = 8192;
@@ -806,7 +806,7 @@ int fdIntoMemory(int fd, char **data, int *len, bool inparts)
 	return 1;
 }
 
-int fileIntoMemory(const char *filename, char **data, int *len, bool inparts)
+int fileIntoMemory(const char *filename, char **data, int *len, int inparts)
 {
 	static int fh;
 	char ftype;
@@ -1265,13 +1265,16 @@ bool lsattrChars(const char *buf, char *dest)
 	bool rc = true;
 	const char *s;
 	char c, *t;
-	static const char ok_chars[] = "lstikpmy";
+	const char * ok_chars = "lstikpmy";
+	if(cw->imapMode2) ok_chars = "uyftdlzr";
+	if(cw->imapMode3) ok_chars = "uyftdlz";
+	if(cw->ircoMode1) ok_chars = "ct";
 	char used[26];
 	memset(used, 0, sizeof(used));
 	t = dest;
 	for (s = buf; (c = *s); ++s) {
-		if (isspaceByte(c))
-			continue;
+		if (isspaceByte(c)) continue;
+		if((cw->imapMode2|cw->imapMode3) && c == 's') c = 'z';
 		if (!strchr(ok_chars, c)) {
 			rc = false;
 			continue;
